import express from 'express';
import session from 'express-session';
import { TypeormStore } from 'connect-typeorm';
import 'reflect-metadata';

import routes from './routes.js';
import dataSourceRepo from './typeorm/data-source.repo.js';
import { Session } from './typeorm/entity/Session.entity.js';

import 'express-async-errors';
import './env.js';

const listen_host = process.env.LISTEN_HOST ?? '0.0.0.0';
const listen_port = parseInt(process.env.LISTEN_PORT ?? '80');

await dataSourceRepo.initialize();
await dataSourceRepo.runMigrations();

const app = express();

declare module "express-session" {
    interface SessionData {
        selection: number[] | null
    }
}

app.use(express.json());
app.use(session({
    resave: false,
    saveUninitialized: false,
    store: new TypeormStore({
        cleanupLimit: 2,
        limitSubquery: false,
        ttl: 3600,
    }).connect(dataSourceRepo.getRepository(Session)),
    secret: 'keyboard cat',
    cookie: {
        httpOnly: true,
        sameSite: true
    }
}));

app.use('/api', routes());

app.listen(listen_port, listen_host, () => {
    console.log(`Listening on ${listen_host}:${listen_port}`)
});