import { IRouter, Router } from 'express';
import dataSourceRepo from '../typeorm/data-source.repo.js';
import { DataRow } from '../typeorm/entity/DataRow.entity.js';

export default function(): IRouter {
    const app = Router();
    app.get('/list', async (req, res) => {
        const [page, pageSz, search] = [
            parseInt(req.query.page as string | undefined),
            parseInt((req.query.page_sz ?? '20').toString()),
            req.query.search as string | undefined
        ];
        if (pageSz <= 0) {
            res.status(400);
            res.send('invalid page_sz');
            return;
        }

        const query = dataSourceRepo.getRepository(DataRow).createQueryBuilder('data');
        if (!Number.isNaN(page)) {
            query.take(pageSz);
            query.skip(page * pageSz);
        }
        if (search !== undefined) {
            query.where('data like :search', { search });
        }

        const data = await query.getMany();
        res.send(data);
    })

    app.put('/', async (req, res) => {
        const data = req.body.data;
        if (!data) {
            res.send(400);
            return;
        }

        const row = new DataRow();
        row.data = data;
        await dataSourceRepo.getRepository(DataRow).insert(row);

        res.status(200);
        res.send('');
        return;
    })

    return app;
}