import ky from "ky";

export type DataRowSearchOptions = {
    page?: number,
    page_sz?: number,
    search?: string
}

export class DataRow {
    constructor(
        public id: number,
        public data: string
    ) { }

    static reviveJSON(data: { id: number, data: string }): DataRow {
        return new DataRow(data.id, data.data);
    }

    static async find(options?: DataRowSearchOptions): Promise<DataRow[]> {
        const req = await ky('/api/data/list', {
            searchParams: options,
            cache: 'no-cache'
        });

        const raw = await req.json<any[]>();
        return raw.map(this.reviveJSON);
    }

    static async create(data: string): Promise<void> {
        await ky('/api/data', {
            method: 'PUT',
            json: {
                data
            }
        });
    }
}