import { useState } from "preact/hooks";
import { SearchIcon } from "./SearchIcon";
import { TargetedEvent } from "preact/compat";

import styles from './input.module.scss';

export type SearchBarProps = {
    default?: string,
    placeholder?: string,
    onChange?: (data: string) => void,
    onSearch?: (data: string) => void
};
export function SearchBar({ default: def, placeholder, onChange, onSearch }: SearchBarProps) {
    const [ query, setQuery ] = useState(def ?? '');

    function updateValue(e: TargetedEvent<HTMLInputElement>) {
        setQuery(e.currentTarget.value);
        if (onChange) onChange(e.currentTarget.value);
    }

    return (
        <div className={styles.input}>
            <SearchIcon />
            <input type='text' value={query} onChange={updateValue} placeholder={placeholder} />
            <button onClick={onSearch ? () => onSearch(query) : undefined}>go</button>
        </div>
    )
}